Keyboard shortcuts — Pootle 2.6.1 documentation

# Keyboard shortcuts

New in version 2.5.

## Global

Action | Shortcut
--- | ---
Content Zoom Out | `Ctrl+Shift+-`
Reset Content Zoom | `Ctrl+Shift+0`
Content Zoom In | `Ctrl+Shift+"+"`

## Editing

Action | Current shortcut | Proposed shortcut
--- | --- | ---
Submit and move to next translation | `Ctrl+Enter` |
Toggle the ‘Needs work’ flag | `Ctrl+Space` |
Toggle the suggest/submit mode | `Ctrl+Shift+Space` |
Copy the contents from the original language |  | `Alt+Down`
Select previous placeable | `Ctrl+J` |
Select next placeable | `Ctrl+K` |
Copy the selected placeable to the target | `Ctrl+L` |
Focus on comments field |  | `Ctrl+Shift+C`

## Navigation

Action | Shortcut | Alternative Shortcut
--- | --- | ---
Move to previous string | `Ctrl+Up` | `Ctrl+,`
Move to next string | `Ctrl+Down` | `Ctrl+.`
Move to the first string | `Ctrl+Shift+Home` |
Move to the last string | `Ctrl+Shift+End` |
Move up 10 strings | `Ctrl+Shift+Page Up` | `Ctrl+Shift+,`
Move down 10 strings | `Ctrl+Shift+Page Down` | `Ctrl+Shift+.`
Select search box | `Ctrl+Shift+S` |
Select page number | `Ctrl+Shift+N` |